==> 0.4.2.0-nix-src.tgz: PtokaX/core/TextFileManager.h <==
/*
 * PtokaX - hub server for Direct Connect peer to peer network.

 * Copyright (C) 2002-2005  Ptaczek, Ptaczek at PtokaX dot org
 * Copyright (C) 2004-2011  Petr Kozelka, PPK at PtokaX dot org

 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3
 * as published by the Free Software Foundation.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

//---------------------------------------------------------------------------
#ifndef TextFileManagerH
#define TextFileManagerH
//---------------------------------------------------------------------------
struct User;
//---------------------------------------------------------------------------

class TextFileMan {
private:
    struct TextFile {
        ~TextFile();

        char * sCommand, * sText;
        TextFile * prev, * next;
    };

    TextFile * TextFiles;
public:
	TextFileMan();
	~TextFileMan();

	bool ProcessTextFilesCmd(User * u, char * cmd, bool fromPM = false);
	void RefreshTextFiles();
};
//---------------------------------------------------------------------------
extern TextFileMan *TextFileManager;
//--------------------------------------------------------------------------- 

#endif

==> 0.5.0.1-nix-src.tgz: PtokaX/core/TextFileManager.h <==
/*
 * PtokaX - hub server for Direct Connect peer to peer network.

 * Copyright (C) 2002-2005  Ptaczek, Ptaczek at PtokaX dot org
 * Copyright (C) 2004-2013  Petr Kozelka, PPK at PtokaX dot org

 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3
 * as published by the Free Software Foundation.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

//---------------------------------------------------------------------------
#ifndef TextFileManagerH
#define TextFileManagerH
//---------------------------------------------------------------------------
struct User;
//---------------------------------------------------------------------------

class clsTextFilesManager {
private:
    struct TextFile {
        ~TextFile();

        char * sCommand, * sText;
        TextFile * prev, * next;
    };

    TextFile * TextFiles;
public:
    static clsTextFilesManager * mPtr;

	clsTextFilesManager();
	~clsTextFilesManager();

	bool ProcessTextFilesCmd(User * u, char * cmd, bool fromPM = false) const;
	void RefreshTextFiles();
};
//---------------------------------------------------------------------------

#endif
